@@ -3,7 +3,7 @@ import asyncio
 import logging
 import time
 from dataclasses import dataclass
-from typing import Any
+from typing import Any, Callable, Awaitable
 
 _CONNECTION_DEFAULT_TIMEOUT = 5.0
 _READ_DEFAULT_TIMEOUT = 5.0
@@ -59,11 +59,11 @@ class WpSocketClient:
     """Wall Pad Socket Client"""
     _reader: asyncio.StreamReader
     _writer: asyncio.StreamWriter
+    async_receive_handler: Callable[[bytes], Awaitable[None]]
 
     def __init__(self, host: str, port: int, **kwds):
         self.host = host
         self.port = port
-        self.async_receive_handler = None
         self._config = WpSocketConfig(
             kwds.pop('connection_timeout', _CONNECTION_DEFAULT_TIMEOUT),
             kwds.pop('read_timeout', _READ_DEFAULT_TIMEOUT),
